set linesize 32000
set pagesize 1000
set head on
set echo on
set termout on
set trimspool on

spool testcase.log

-- show version

select banner from v$version;

-- create test table noparallel

drop table test;

create table test noparallel as select * from dba_tables;

-- get outline hint with parallel plan due to hint
-- assumes existance of plan_table created by
-- $ORACLE_HOME/rdbms/admin/utlxplan.sql

explain plan into plan_table for 
select /*+ parallel(test,8) */ sum(blocks) from test;

-- show plan with outline hint

set markup html preformat on

select * from table(dbms_xplan.display('PLAN_TABLE',NULL,'ADVANCED'));

-- run query with just outline hint

select   /*+
      BEGIN_OUTLINE_DATA
      FULL(@"SEL$1" "TEST"@"SEL$1")
      OUTLINE_LEAF(@"SEL$1")
      ALL_ROWS
      DB_VERSION('19.1.0')
      OPTIMIZER_FEATURES_ENABLE('19.1.0')
      IGNORE_OPTIM_EMBEDDED_HINTS
      END_OUTLINE_DATA
  */ sum(blocks) from test;

-- get plan - is not parallel

select * from table(dbms_xplan.display_cursor(null,null,'ALL'));

-- run with parallel and outline hints

select   /*+ parallel(test,8)
      BEGIN_OUTLINE_DATA
      FULL(@"SEL$1" "TEST"@"SEL$1")
      OUTLINE_LEAF(@"SEL$1")
      ALL_ROWS
      DB_VERSION('19.1.0')
      OPTIMIZER_FEATURES_ENABLE('19.1.0')
      IGNORE_OPTIM_EMBEDDED_HINTS
      END_OUTLINE_DATA
  */ sum(blocks) from test;
  
-- get plan - is parallel

select * from table(dbms_xplan.display_cursor(null,null,'ALL'));

spool off
